@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 from config import Config
 from diff import diff
+from init import init
+from counter import Counter
